==> assertj-build-3.25.3.tar.gz: assertj-assertj-build-3.25.3/assertj-core/src/test/java/org/assertj/core/api/float_/FloatAssert_isZero_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2024 the original author or authors.
 */
package org.assertj.core.api.float_;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.api.Assertions.catchThrowable;
import static org.assertj.core.test.ErrorMessagesForTest.shouldBeEqualMessage;
import static org.mockito.Mockito.verify;

import org.assertj.core.api.FloatAssert;
import org.assertj.core.api.FloatAssertBaseTest;
import org.junit.jupiter.api.Test;

/**
 * Tests for <code>{@link FloatAssert#isZero()}</code>.
 *
 * @author Alex Ruiz
 */
class FloatAssert_isZero_Test extends FloatAssertBaseTest {

  @Override
  protected FloatAssert invoke_api_method() {
    return assertions.isZero();
  }

  @Override
  protected void verify_internal_effects() {
    verify(floats).assertIsZero(getInfo(assertions), getActual(assertions));
  }

  @Test
  void should_pass_with_primitive_negative_zero() {
    // GIVEN
    final float negativeZero = -0.0f;
    // THEN
    assertThat(negativeZero).isZero();
  }

  @Test
  void should_pass_with_primitive_positive_zero() {
    // GIVEN
    final float positiveZero = 0.0f;
    // THEN
    assertThat(positiveZero).isZero();
  }

  @Test
  void should_pass_with_Float_positive_zero() {
    // GIVEN
    final Float positiveZero = 0.0f;
    // THEN
    assertThat(positiveZero).isZero();
  }

  @Test
  void should_fail_with_non_zero() {
    // GIVEN
    final float notZero = 1.0f;

    // WHEN
    Throwable error = catchThrowable(() -> assertThat(notZero).isZero());

    // THEN
    assertThat(error).isInstanceOf(AssertionError.class)
                     .hasMessage(shouldBeEqualMessage("1.0f", "0.0f"));
  }

  @Test
  void should_fail_with_Float_negative_zero() {
    // GIVEN
    final Float negativeZero = -0.0f;

    // WHEN
    Throwable error = catchThrowable(() -> assertThat(negativeZero).isZero());

    // THEN
    assertThat(error).isInstanceOf(AssertionError.class)
                     .hasMessage(shouldBeEqualMessage("-0.0f", "0.0f"));
  }

}

==> assertj-build-3.27.6.tar.gz: assertj-assertj-build-3.27.6/assertj-core/src/test/java/org/assertj/core/api/float_/FloatAssert_isZero_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2025 the original author or authors.
 */
package org.assertj.core.api.float_;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.api.Assertions.catchThrowable;
import static org.assertj.core.testkit.ErrorMessagesForTest.shouldBeEqualMessage;
import static org.mockito.Mockito.verify;

import org.assertj.core.api.FloatAssert;
import org.assertj.core.api.FloatAssertBaseTest;
import org.junit.jupiter.api.Test;

/**
 * Tests for <code>{@link FloatAssert#isZero()}</code>.
 *
 * @author Alex Ruiz
 */
class FloatAssert_isZero_Test extends FloatAssertBaseTest {

  @Override
  protected FloatAssert invoke_api_method() {
    return assertions.isZero();
  }

  @Override
  protected void verify_internal_effects() {
    verify(floats).assertIsZero(getInfo(assertions), getActual(assertions));
  }

  @Test
  void should_pass_with_primitive_negative_zero() {
    // GIVEN
    final float negativeZero = -0.0f;
    // THEN
    assertThat(negativeZero).isZero();
  }

  @Test
  void should_pass_with_primitive_positive_zero() {
    // GIVEN
    final float positiveZero = 0.0f;
    // THEN
    assertThat(positiveZero).isZero();
  }

  @Test
  void should_pass_with_Float_positive_zero() {
    // GIVEN
    final Float positiveZero = 0.0f;
    // THEN
    assertThat(positiveZero).isZero();
  }

  @Test
  void should_fail_with_non_zero() {
    // GIVEN
    final float notZero = 1.0f;

    // WHEN
    Throwable error = catchThrowable(() -> assertThat(notZero).isZero());

    // THEN
    assertThat(error).isInstanceOf(AssertionError.class)
                     .hasMessage(shouldBeEqualMessage("1.0f", "0.0f"));
  }

  @Test
  void should_fail_with_Float_negative_zero() {
    // GIVEN
    final Float negativeZero = -0.0f;

    // WHEN
    Throwable error = catchThrowable(() -> assertThat(negativeZero).isZero());

    // THEN
    assertThat(error).isInstanceOf(AssertionError.class)
                     .hasMessage(shouldBeEqualMessage("-0.0f", "0.0f"));
  }

}
